package
Version:
v0.0.0-...-fa69716
Opens a new window with list of versions in this module.
Published: Apr 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 16
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type ToolUse struct {
XMLName xml.Name `xml:"tool_use"`
GenID string `xml:"id"`
Name string `xml:"name"`
Arguments string `xml:"arguments"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.