utils

package
v0.0.0-...-fa69716 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Subscribe          = bus.Subscribe
	SubscribeOnce      = bus.SubscribeOnce
	SubscribeWithBlock = bus.SubscribeWithBlock
	Unsubscribe        = bus.Unsubscribe
	Publish            = bus.Publish
)

Functions

func ComputeHierarchyStructHash

func ComputeHierarchyStructHash(parent, child interface{}, collisionCount *int32) string

func ComputeStructHash

func ComputeStructHash(template interface{}, collisionCount *int32) string

func CutToSafeLength

func CutToSafeLength(content string, safeLen int) string

func DeepHashObject

func DeepHashObject(hasher hash.Hash, objectToWrite interface{})

DeepHashObject writes specified object to hash using the spew library which follows pointers and prints actual values of the nested objects ensuring the hash does not change when a pointer changes.

func ExtractJSON

func ExtractJSON(response string) string

func GrepC

func GrepC(content string, C int, keywords ...string) string

func Res2Str

func Res2Str(obj interface{}) string

Types

This section is empty.

Directories

Path Synopsis

Jump to