Documentation
¶
Index ¶
- Variables
- func ComputeHierarchyStructHash(parent, child interface{}, collisionCount *int32) string
- func ComputeStructHash(template interface{}, collisionCount *int32) string
- func CutToSafeLength(content string, safeLen int) string
- func DeepHashObject(hasher hash.Hash, objectToWrite interface{})
- func ExtractJSON(response string) string
- func GrepC(content string, C int, keywords ...string) string
- func Res2Str(obj interface{}) string
Constants ¶
This section is empty.
Variables ¶
var ( Subscribe = bus.Subscribe SubscribeOnce = bus.SubscribeOnce SubscribeWithBlock = bus.SubscribeWithBlock Unsubscribe = bus.Unsubscribe Publish = bus.Publish )
Functions ¶
func ComputeStructHash ¶
func CutToSafeLength ¶
func DeepHashObject ¶
DeepHashObject writes specified object to hash using the spew library which follows pointers and prints actual values of the nested objects ensuring the hash does not change when a pointer changes.
func ExtractJSON ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.